@@ -1,8 +1,7 @@
 /*
  * QEstEidCommon
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,7 +26,7 @@
 #define EESTI "sisene.www.eesti.ee"
 #define SK "www.openxades.org"
 
-class SSLObj;
+class SSLConnectPrivate;
 class SSLConnect: public QObject
 {
 	Q_OBJECT
@@ -40,18 +39,27 @@ public:
 		PictureInfo,
 		AccessCert
 	};
+	enum ErrorType {
+		PinCanceledError = 1,
+		PinInvalidError = 2,
+		PinLocked = 3,
+		UnknownError = -1,
+	};
 
 	SSLConnect( QObject *parent = 0 );
 	~SSLConnect();
 
+	ErrorType error() const;
+	QString errorString() const;
 	QByteArray getUrl( RequestType type, const QString &value = "" );
-
 	QString pin() const;
+	QByteArray result() const;
 	void setCard( const QString &card );
 	void setPin( const QString &pin );
-	void setPKCS11( const QString &pkcs11 );
+	void setPKCS11( const QString &pkcs11, bool unload = true );
 	void setReader( int reader );
+	void waitForFinished( RequestType type, const QString &value = "" );
 
 private:
-	SSLObj	*obj;
+	SSLConnectPrivate	*d;
 };
