@@ -116,6 +116,21 @@
         <translation>Идентификатор ключа заглавия</translation>
     </message>
 </context>
+<context>
+    <name>CheckConnection</name>
+    <message>
+        <source>Check proxy settings</source>
+        <translation>Проверте настройки прокси</translation>
+    </message>
+    <message>
+        <source>Check proxy username and password</source>
+        <translation>Проверьте имя пользователя и пароль прокси</translation>
+    </message>
+    <message>
+        <source>Check internet connection</source>
+        <translation>Проверьте подключение к Интернету</translation>
+    </message>
+</context>
 <context>
     <name>Common</name>
     <message>
@@ -150,10 +165,6 @@
         <source>valid</source>
         <translation>действительны</translation>
     </message>
-    <message>
-        <source>Your certificates will be expire</source>
-        <translation>Сертификаты будут недействительны</translation>
-    </message>
     <message>
         <source>expired</source>
         <translation>устарели</translation>
@@ -162,6 +173,10 @@
         <source>Open utility</source>
         <translation>Открыть средство управления</translation>
     </message>
+    <message>
+        <source>Your certificates will expire soon</source>
+        <translation>Сертификаты скоро будут недействительны</translation>
+    </message>
 </context>
 <context>
     <name>PinDialog</name>
@@ -191,7 +206,58 @@
     </message>
 </context>
 <context>
-    <name>QObject</name>
+    <name>SSLConnect</name>
+    <message>
+        <source>PIN canceled</source>
+        <translation>Введение PIN отменено</translation>
+    </message>
+    <message>
+        <source>Invalid PIN</source>
+        <translation>Неверный PIN</translation>
+    </message>
+    <message>
+        <source>failed to list slots</source>
+        <translation>ошибка при чтении слотов pkcs11</translation>
+    </message>
+    <message>
+        <source>token failed</source>
+        <translation>ошибка при загрузке &quot;token&quot;-а</translation>
+    </message>
+    <message>
+        <source>no token available</source>
+        <translation>не найдено ни одного &quot;token&quot;-а</translation>
+    </message>
+    <message>
+        <source>no certificate available</source>
+        <translation>Нет доступного сертификата</translation>
+    </message>
+    <message>
+        <source>no key matching certificate available</source>
+        <translation>не найдено подходящего сертификата</translation>
+    </message>
+    <message>
+        <source>Failed to connect to host. Are you connected to the internet?</source>
+        <translation>Отсутствует подключение к интернету!</translation>
+    </message>
+    <message>
+        <source>Pin locked</source>
+        <translation>PIN заблокирован</translation>
+    </message>
+    <message>
+        <source>failed to load pkcs11 module &apos;%1&apos;</source>
+        <translation>ошибка при загрузке модуля pkcs11 &apos;%1&apos;</translation>
+    </message>
+    <message>
+        <source>Certificate is not valid</source>
+        <translation>Сертификат не действителен</translation>
+    </message>
+</context>
+<context>
+    <name>SslCertificate</name>
+    <message>
+        <source>All application policies</source>
+        <translation>Все полисы приложений</translation>
+    </message>
     <message>
         <source>Proves your identity to a remote computer</source>
         <translation>Подтверждает Вашу личность на отдалённом компьютере</translation>
@@ -204,17 +270,13 @@
         <source>OCSP signing</source>
         <translation>OCSP подписывание</translation>
     </message>
-    <message>
-        <source>All application policies</source>
-        <translation>Все полисы приложений</translation>
-    </message>
     <message>
         <source>Digital signature</source>
         <translation>Дигитальная подпись</translation>
     </message>
     <message>
         <source>Non repudiation</source>
-        <translation>Не отрицательно</translation>
+        <translation>Невозможность отказа</translation>
     </message>
     <message>
         <source>Key encipherment</source>
@@ -244,33 +306,5 @@
         <source>Decipher only</source>
         <translation>Только разшифровка</translation>
     </message>
-    <message>
-        <source>failed to load pkcs11 module</source>
-        <translation>ошибка при загрузке модуля pkcs11</translation>
-    </message>
-    <message>
-        <source>failed to list slots</source>
-        <translation>ошибка при чтении слотов pkcs11</translation>
-    </message>
-    <message>
-        <source>token failed</source>
-        <translation>ошибка при загрузке &quot;token&quot;-а</translation>
-    </message>
-    <message>
-        <source>no token available</source>
-        <translation>не найдено ни одного &quot;token&quot;-а</translation>
-    </message>
-    <message>
-        <source>no key matching certificate available</source>
-        <translation>не найдено подходящего сертификата</translation>
-    </message>
-    <message>
-        <source>Failed to connect to host. Are you connected to the internet?</source>
-        <translation>Отсутствует подключение к интернету!</translation>
-    </message>
-    <message>
-        <source>no certificate available</source>
-        <translation>Нет доступного сертификата</translation>
-    </message>
 </context>
 </TS>
