@@ -1,8 +1,7 @@
 /*
  * QEstEidUtil
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,11 +21,15 @@
 
 #include "CertUpdate.h"
 
-#include <smartcard++/helperMacro.h>
+#include "common/PinDialog.h"
+#include "common/SslCertificate.h"
 
 #include <QApplication>
 #include <QDateTime>
 
+#define LENOF(a) (sizeof(a)/sizeof(*(a)))
+#define MAKEVECTOR(a) ByteVec(a,a + LENOF(a) )
+
 #define HEADER 28
 
 CertUpdate::CertUpdate( int reader, QObject *parent )
@@ -37,15 +40,17 @@ CertUpdate::CertUpdate( int reader, QObject *parent )
 ,	step( 0 )
 ,	serverStep( 0 )
 ,	generateKeys( false )
+,	m_authCert( 0 )
 {
-	cardMgr = new SmartCardManager();
+	cardMgr = new PCSCManager();
 
 	card = new EstEidCard(*cardMgr);
 	if ( !card->isInReader( reader ) )
 		throw std::runtime_error( "no card in specified reader" );
 	card->connect( reader );
-	//ByteVec c = card->cardChallenge();
-	//challenge = (char *)&c[0];
+	m_authCert = new JsCertData( this );
+	m_authCert->loadCert( card, JsCertData::AuthCert );
+	updateUrl = QUrl( ( !m_authCert || m_authCert->isTest() ) ? "http://demo.digidoc.ee:80/iduuendusproxy/" : "http://www.sk.ee:80/id-kontroll2/usk/" );
 	QByteArray c( QByteArray::number( QDateTime::currentDateTime().toTime_t() ) );
 	memcpy( (void*)challenge, c, 8 );
 
@@ -54,8 +59,10 @@ CertUpdate::CertUpdate( int reader, QObject *parent )
 
 CertUpdate::~CertUpdate()
 {
-	if ( sock && sock->state() != QTcpSocket::ConnectedState )
+	if ( sock && sock->state() == QTcpSocket::ConnectedState )
 		sock->disconnectFromHost();
+	if ( m_authCert )
+		delete m_authCert;
 	if ( card )
 		delete card;
 	if ( cardMgr )
@@ -66,7 +73,7 @@ bool CertUpdate::checkConnection() const
 {
 	if ( sock && sock->state() != QTcpSocket::ConnectedState )
 	{
-		sock->connectToHost( "demo.digidoc.ee", 80 );
+		sock->connectToHost( updateUrl.host(), updateUrl.port() );
 		if ( !sock->waitForConnected( 5000 ) )
 			return false;
 	}
@@ -77,17 +84,16 @@ bool CertUpdate::checkUpdateAllowed()
 {
 	QByteArray result = QByteArray::fromHex( runStep( step ) );
 	if ( result.isEmpty() || result.size() != 22 || result.size() < 22 )
-		throwError( tr("Check internet connection") );
+		throwError( tr("Check internet connection").toUtf8() );
 	if ( result.at(4) == 0x06 )
 		generateKeys = true;
 	if ( !(result.size() > 20 && result.at( 21 ) == 0x00) )
-		throwError( tr("update not allowed!") );
+		throwError( tr("update not allowed!").toUtf8() );
 	return true;
 }
 
-void CertUpdate::startUpdate( const QString &pin )
+void CertUpdate::startUpdate()
 {
-	m_pin = pin;
 	QByteArray result;
 	for( step = 1; step < 36; step++ )
 		result = runStep( step, result );
@@ -119,11 +125,26 @@ QByteArray CertUpdate::runStep( int s, QByteArray result )
 		break;
 	case 4:
 		{
+			PinDialog *p = new PinDialog( qApp->activeWindow() );
 			try {
+				SslCertificate c = m_authCert->cert();
+				if ( !card->isSecureConnection() && m_pin.isEmpty() )
+				{
+					p->init( PinDialog::Pin1Type, c.toString( c.isTempel() ? "CN serialNumber" : "GN SN serialNumber" ) );
+					if( !p->exec() )
+						throw std::runtime_error( "" );
+					m_pin = p->text();
+				} else if ( card->isSecureConnection() ) {
+					p->init( PinDialog::Pin1PinpadType, c.toString( c.isTempel() ? "CN serialNumber" : "GN SN serialNumber" ) );
+					p->show();
+					QApplication::processEvents();
+				}
 				card->enterPin( EstEidCard::PIN_AUTH, PinString( m_pin.toLatin1() ) );
 			} catch( const AuthError &e ) {
+				delete p;
 				throw std::runtime_error( "step4 auth error: " + e.desc );
 			}
+			delete p;
 			break;
 		}
 	case 5: break;
@@ -323,17 +344,19 @@ QByteArray CertUpdate::runStep( int s, QByteArray result )
 			if ( result.isEmpty() || result.size() != 147 || result.size() < 134 )
 				throw std::runtime_error( "step21a" );
 		
-			if ((unsigned char)result.at( 132 ) == 0x34 && (unsigned char)result.at( 133 ) >= 0x80 )
+			QByteArray tmpResult = result;
+
+			result = QByteArray::fromHex( queryServer( s, result ).remove( 0, 16 ) );
+			if ( result.isEmpty() || result.size() != 22 )
+				throw std::runtime_error( "step21b" );
+
+			if ((unsigned char)tmpResult.at( 132 ) == 0x34 && (unsigned char)tmpResult.at( 133 ) >= 0x80 )
 			{
 				runStep( 3 );
 				runStep( 4 );
 				runStep( 11 );
 				runStep( 12 );
 				step = 13;
-			} else {
-				result = QByteArray::fromHex( queryServer( s, result ).remove( 0, 16 ) );
-				if ( result.isEmpty() || result.size() != 22 )
-					throw std::runtime_error( "step21b" );
 			}
 			break;
 		}
@@ -401,11 +424,13 @@ QByteArray CertUpdate::runStep( int s, QByteArray result )
 			if ( result.isEmpty() || result.size() != 147 || result.size() < 134 )
 				throw std::runtime_error( "step25a" );
 
-			QByteArray tmpResult = QByteArray::fromHex( queryServer( s, result ).remove( 0, 16 ) );
-			if ( tmpResult.isEmpty() || tmpResult.size() != 114 )
+			QByteArray tmpResult = result;
+
+			result = QByteArray::fromHex( queryServer( s, result ).remove( 0, 16 ) );
+			if ( result.isEmpty() || result.size() != 114 )
 				throw std::runtime_error( "step25b" );
 
-			if ( (unsigned char)result.at( 133 ) >= 0x80 )
+			if ( (unsigned char)tmpResult.at( 132 ) == 0x34 && (unsigned char)tmpResult.at( 133 ) >= 0x80 )
 			{
 				runStep( 3 );
 				runStep( 4 );
@@ -416,10 +441,7 @@ QByteArray CertUpdate::runStep( int s, QByteArray result )
 				runStep( 16 );
 				runStep( 17 );
 				step = 21;
-			} else { //start generating certs
-				result = tmpResult;
 			}
-
 			break;
 		}
 	case 26:
@@ -531,7 +553,7 @@ QByteArray CertUpdate::runStep( int s, QByteArray result )
 QByteArray CertUpdate::queryServer( int s, QByteArray result )
 {
 	if ( !checkConnection() )
-		throwError( tr("Check internet connection") );
+		throwError( tr("Check internet connection").toUtf8() );
 
 	const char serviceCode[] = { 0x31, 0x00 };
 	QByteArray packet;
@@ -676,7 +698,11 @@ QByteArray CertUpdate::queryServer( int s, QByteArray result )
 		return QByteArray();
 	}
 	qDebug() << "step " << s << " serverStep: " << serverStep << " send: " << packet.toUpper();
-	QByteArray data = "POST http://demo.digidoc.ee/iduuendusproxy/ HTTP/1.1\r\nHost: demo.digidoc.ee\r\nContent-Type: text/plain\r\nContent-Length: " + QByteArray::number(packet.size()) + "\r\nConnection: close\r\n\r\n" + packet.toUpper() + "\r\n";
+	QByteArray data = "POST ";
+	data += updateUrl.path();
+	data += " HTTP/1.1\r\nHost: ";
+	data += updateUrl.host();
+	data += "\r\nContent-Type: text/plain\r\nContent-Length: " + QByteArray::number(packet.size()) + "\r\nConnection: close\r\n\r\n" + packet.toUpper() + "\r\n";
 	sock->write( data );
 	if ( !sock->waitForReadyRead( 60000 ) )
 	{
@@ -688,5 +714,21 @@ QByteArray CertUpdate::queryServer( int s, QByteArray result )
 		result = result.remove( 0, result.indexOf( "\r\n\r\n" ) + 4 );
 	qDebug() << "step " << s << " serverStep: " << serverStep << " receive: " << result;
 	sock->disconnectFromHost();
+
+	//veakoodide kontroll
+	QByteArray hex = QByteArray::fromHex( result );
+	if ( hex.size() > 4 )
+	{
+		switch( hex.at(4) )
+		{
+			case 0x01: throw std::runtime_error( tr( "Server sai vale arvu baite, samm: %1" ).arg( s ).toStdString() );
+			case 0x02:
+			case 0x03:
+			case 0x07:
+			case 0x08: throw std::runtime_error( tr( "Serveri ts tekkisid vead, samm: %1" ).arg( s ).toStdString() );
+			case 0x04: throw std::runtime_error( tr( "Kaardi vastuse parsimisel tekkis viga, samm: %1" ).arg( s ).toStdString() );
+			case 0x05: throw std::runtime_error( tr( "Sertifitseerimiskeskus ei vasta, samm: %1" ).arg( s ).toStdString() );
+		}
+	}
 	return result;
 }
