@@ -1,8 +1,7 @@
 /*
  * QEstEidUtil
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,9 +23,10 @@
 
 #include <QObject>
 #include <QTcpSocket>
+#include <QUrl>
 
 #include "jscardmanager.h"
-#include "smartcard++/esteid/EstEidCard.h"
+#include <smartcardpp/esteid/EstEidCard.h>
 
 class CertUpdate: public QObject
 {
@@ -38,14 +38,14 @@ public:
 	~CertUpdate();
 
 	bool checkUpdateAllowed();
-	void startUpdate( const QString &pin );
+	void startUpdate();
 
 private:
 	void throwError( const QString &msg );
 
 	QString m_pin;
 	EstEidCard *card;
-	SmartCardManager *cardMgr;
+	PCSCManager *cardMgr;
 	QTcpSocket *sock;
 	char challenge[8];
 	char personCode[11], documentNumber[8], tmpResult[36], certInfo[33][114];
@@ -56,4 +56,6 @@ private:
 	bool checkConnection() const;
 	QByteArray runStep( int step, QByteArray result = "" );
 	QByteArray queryServer( int step, QByteArray result );
+	JsCertData *m_authCert;
+	QUrl updateUrl;
 };
