@@ -1,8 +1,7 @@
 /*
  * QEstEidUtil
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,10 +21,9 @@
 
 #include "DiagnosticsDialog.h"
 
-#include "smartcard++/common.h"
-#include "smartcard++/DynamicLibrary.h"
-#include "smartcard++/SmartCardManager.h"
-#include "smartcard++/esteid/EstEidCard.h"
+#include <smartcardpp/DynamicLibrary.h>
+#include <smartcardpp/PCSCManager.h>
+#include <smartcardpp/esteid/EstEidCard.h>
 
 #include <QDesktopServices>
 #include <QFile>
@@ -40,6 +38,7 @@
 #include <QProcess>
 #elif defined(Q_OS_MAC)
 #include <Carbon/Carbon.h>
+#include <QProcess>
 #endif
 
 DiagnosticsDialog::DiagnosticsDialog( QWidget *parent )
@@ -56,14 +55,57 @@ DiagnosticsDialog::DiagnosticsDialog( QWidget *parent )
 
 	s << "<b>" << tr("OS:") << "</b> ";
 #if defined(Q_OS_WIN32)
-	switch( QSysInfo::WindowsVersion )
+	OSVERSIONINFOEX osvi;
+	ZeroMemory( &osvi, sizeof( OSVERSIONINFOEX ) );
+	osvi.dwOSVersionInfoSize = sizeof( OSVERSIONINFOEX );
+	if( !GetVersionEx( (OSVERSIONINFO *) &osvi) )
 	{
-	case QSysInfo::WV_2000: s << "Windows 2000"; break;
-	case QSysInfo::WV_XP: s << "Windows XP"; break;
-	case QSysInfo::WV_2003: s << "Windows 2003"; break;
-	case QSysInfo::WV_VISTA: s << "Windows Vista"; break;
-	case QSysInfo::WV_WINDOWS7: s << "Windows 7"; break;
-	default: s << "Unknown version (" << QSysInfo::WindowsVersion << ")";
+		switch( QSysInfo::WindowsVersion )
+		{
+		case QSysInfo::WV_2000: s << "Windows 2000"; break;
+		case QSysInfo::WV_XP: s << "Windows XP"; break;
+		case QSysInfo::WV_2003: s << "Windows 2003"; break;
+		case QSysInfo::WV_VISTA: s << "Windows Vista"; break;
+		case QSysInfo::WV_WINDOWS7: s << "Windows 7"; break;
+		default: s << "Unknown version (" << QSysInfo::WindowsVersion << ")";
+		}
+	} else {
+		switch( osvi.dwMajorVersion )
+		{
+		case 5:
+			{
+				switch( osvi.dwMinorVersion )
+				{
+				case 0:
+					s << "Windows 2000 ";
+					s << ( osvi.wProductType == VER_NT_WORKSTATION ? "Professional" : "Server" );
+					break;
+				case 1:
+					s << "Windows XP ";
+					s << ( osvi.wSuiteMask & VER_SUITE_PERSONAL ? "Home" : "Professional" );
+					break;
+				case 2:
+					if ( GetSystemMetrics( SM_SERVERR2 ) )
+						s << "Windows Server 2003 R2";
+					else if ( osvi.wProductType == VER_NT_WORKSTATION )
+						s << "Windows XP Professional";
+					else
+						s << "Windows Server 2003";
+					break;
+				}
+				break;
+			}	
+		case 6:
+			{
+				switch( osvi.dwMinorVersion )
+				{
+					case 0: s << ( osvi.wProductType == VER_NT_WORKSTATION ? "Windows Vista" : "Windows Server 2008" ); break;
+					case 1: s << ( osvi.wProductType == VER_NT_WORKSTATION ? "Windows 7" : "Windows Server 2008 R2" ); break;
+				}
+				break;
+			}
+		default: s << "Unknown version (" << QSysInfo::WindowsVersion << ")";
+		}
 	}
 #elif defined(Q_OS_LINUX)
 	QProcess p;
@@ -81,11 +123,24 @@ DiagnosticsDialog::DiagnosticsDialog( QWidget *parent )
 #endif
 
 #if defined(Q_OS_WIN)
-#	if defined(Q_OS_WIN64)
-		s << " (" << 64 << ")<br /><br />";
-#	else
-		s << " (" << 32 << ")<br /><br />";
-#	endif
+	QString bits = "32";
+	typedef BOOL (WINAPI *LPFN_ISWOW64PROCESS) (HANDLE, PBOOL);
+	LPFN_ISWOW64PROCESS fnIsWow64Process;
+	BOOL bIsWow64 = false;
+	//check if kernel32 supports this function
+	fnIsWow64Process = (LPFN_ISWOW64PROCESS) GetProcAddress( GetModuleHandle(TEXT("kernel32")), "IsWow64Process" );
+	if ( fnIsWow64Process != NULL )
+	{
+		if ( fnIsWow64Process( GetCurrentProcess(), &bIsWow64 ) )
+			if ( bIsWow64 )
+				bits = "64";
+	} else {
+		SYSTEM_INFO sysInfo;
+		GetSystemInfo( &sysInfo );
+		if ( sysInfo.wProcessorArchitecture == PROCESSOR_ARCHITECTURE_AMD64 )
+			bits = "64";
+	}
+	s << " (" << bits << ")<br /><br />";
 #else
 	s << " (" << QSysInfo::WordSize << ")<br /><br />";
 #endif
@@ -141,10 +196,10 @@ QString DiagnosticsDialog::getReaderInfo() const
 	QTextStream s( &d );
 
 	QHash<QString,QString> readers;
-	SmartCardManager *m = 0;
+	PCSCManager *m = 0;
 	QString reader;
 	try {
-		m = new SmartCardManager();
+		m = new PCSCManager();
 		int readersCount = m->getReaderCount( true );
 		for( int i = 0; i < readersCount; i++ )
 		{
@@ -203,6 +258,14 @@ bool DiagnosticsDialog::isPCSCRunning() const
 	p.waitForFinished();
 	return !p.readAll().trimmed().isEmpty();
 }
+#elif defined(Q_OS_MAC)
+bool DiagnosticsDialog::isPCSCRunning() const
+{
+	QProcess p;
+	p.start( "sh -c \"ps ax | grep -v grep | grep pcscd\"" );
+	p.waitForFinished();
+	return !p.readAll().trimmed().isEmpty();
+}
 #else
 bool DiagnosticsDialog::isPCSCRunning() const { return true; }
 #endif
@@ -221,5 +284,5 @@ void DiagnosticsDialog::save()
 		f.close();
 	}
 	else
-		QMessageBox::warning( this, tr("Error occured"), tr("Failed write to file!") );
+		QMessageBox::warning( this, tr("Error occurred"), tr("Failed write to file!") );
 }
