@@ -7,6 +7,7 @@ function checkAccessKeys(e)
 {
 	if ( !e.altKey )
 		return;
+		
 	var letter = String.fromCharCode(e.keyCode);
 	
 	var buttons = document.getElementById('leftMenus').getElementsByTagName('input');
@@ -33,14 +34,14 @@ function checkAccessKeys(e)
 
 function checkNumeric(e)
 {
-	if ( e.keyCode == 13 || e.keyCode == 9 || e.keyCode == 8 || e.keyCode == 0 || String.fromCharCode(e.keyCode).match(/[\d]/) )
+	if ( e.charCode == 13 || e.charCode == 9 || e.charCode == 8 || e.charCode == 0 || String.fromCharCode(e.charCode).match(/[\d]/) )
 		return true;
 	return false;
 }
 
 function handlekey(nextItem)
 {
-	if ( window.event.keyCode != 13 && window.event.keyCode != 9 )
+	if ( window.event.charCode != 13 && window.event.charCode != 9 )
 		return;
 
 	var el = document.getElementById(nextItem)
@@ -55,13 +56,13 @@ function handlekey(nextItem)
 
 function checkEnter( e, obj )
 {
-	if ( e.keyCode == 13 && ( typeof obj.click != "undefined" ) && obj.click )
+	if ( e.charCode == 13 && ( typeof obj.click != "undefined" ) && obj.click )
 		obj.click();
 }
 
 function cardInserted(i)
 {
-	//alert("Kaart sisestati lugejasse " + cardManager.getReaderName(i))
+	//alert("Kaart sisestati lugejasse " + i + " - " + cardManager.getReaderName(i))
 	checkReaderCount();
 	setActive('cert',document.getElementById('buttonCert'));
 
@@ -69,6 +70,7 @@ function cardInserted(i)
 	try {
 		if ( !cardManager.isInReader( activeCardId ) )
 		{
+			disableFields();
 			document.getElementById('cardInfoNoCard').style.display='none';
 			activeCardId = "";
 			emailsLoaded = false;
@@ -99,6 +101,7 @@ function cardInserted(i)
 	document.getElementById( 'forUpdate' ).innerHTML += ".";
 	if ( !inReader && activeCardId != '' )
 		readCardData();
+    cardManager.allowRead();
 }
 
 function cardRemoved(i)
@@ -135,10 +138,12 @@ function cardRemoved(i)
 	document.getElementById( 'forUpdate' ).innerHTML += ".";
 	if ( !inReader )
 		readCardData();
+    cardManager.allowRead();
 }
 
 function selectReader()
 {
+	setActive('cert',document.getElementById('buttonCert'));
 	extender.showLoading( _('loadCardData') );
 	disableFields();
 	var select = document.getElementById('readerSelect'); 
@@ -181,36 +186,38 @@ function checkReaderCount()
 	if ( cards < 2 )
 	{
 		document.getElementById( 'headerMenus' ).style.right = '100px';
-		reader.style.display = 'none';
+                document.getElementById( 'readerSelectDiv' ).style.display = 'none';
 	} else {
-		document.getElementById( 'headerMenus' ).style.right = '190px';
-		reader.style.display = 'block';
+                document.getElementById( 'headerMenus' ).style.right = '200px';
+                document.getElementById( 'readerSelectDiv' ).style.display = 'block';
 	}
 }
 
-function readCardData()
+function readCardData( translate )
 {
 	try {
-		if ( cardManager.getReaderCount() == 0 || !esteidData.canReadCard() )
+		if ( translate == null )
 		{
-			disableFields();
-			return;
-		} else
-			enableFields();
+			if ( cardManager.getReaderCount() == 0 || !esteidData.canReadCard() )
+			{
+				disableFields();
+				return;
+			} else
+				enableFields();
 
-		if ( activeCardId == "" )
-			activeCardId = esteidData.getDocumentId();
-
-		checkReaderCount();
+			if ( activeCardId == "" )
+				activeCardId = esteidData.getDocumentId();
 
+			checkReaderCount();
+		}
 		var pukRetry = esteidData.getPukRetryCount();
 		var esteidIsValid = esteidData.isValid();
 		
 		document.getElementById('documentId').innerHTML = activeCardId;
-		document.getElementById('expiry').innerHTML = esteidData.getExpiry( language );
 		document.getElementById('email').innerHTML = esteidData.authCert.getEmail();
 		document.getElementById('labelCardValidity').innerHTML = _( esteidIsValid ? 'labelIsValid' : 'labelIsInValid' );
 		document.getElementById('labelCardValidity').style.color = esteidIsValid ? '#509b00' : '#e80303';
+		document.getElementById('labelCardValidTo').innerHTML = !esteidIsValid ? _('labelCardGetNew') : _('labelCardValidTill') + '<span id="expiry" style="color: #355670;">' + esteidData.getExpiry( language ) + '</span>';
 
 		if ( esteidData.authCert.isTempel() )
 		{
@@ -238,7 +245,7 @@ function readCardData()
 		
 		document.getElementById('authCertValidTo').innerHTML = esteidData.authCert.getValidTo( language );
 		var days = esteidData.authCert.validDays();
-		if ( days >= 0 && days <= 105 )
+		if ( days >= 0 && days <= 105 && pin1Retry != 0 )
 		{
 			document.getElementById('authCertWillExpire').style.display = 'block';
 			document.getElementById('authCertWillExpire').innerHTML = _( 'labelCertWillExpire' ).replace( /%d/, days );
@@ -249,7 +256,7 @@ function readCardData()
 
 		document.getElementById('signCertValidTo').innerHTML = esteidData.signCert.getValidTo( language );
 		days = esteidData.signCert.validDays();
-		if ( days >= 0 && days <= 105 )
+		if ( days >= 0 && days <= 105 && pin2Retry != 0 )
 		{
 			document.getElementById('signCertWillExpire').style.display = 'block';
 			document.getElementById('signCertWillExpire').innerHTML = _( 'labelCertWillExpire' ).replace( /%d/, days );
@@ -270,6 +277,9 @@ function readCardData()
 			document.getElementById('authCertStatus').innerHTML=_( esteidData.authCert.isValid() ? 'validBlocked' : 'invalidBlocked' );
 			document.getElementById('authKeyText').style.display='none';
 			document.getElementById('authKeyBlocked').style.display='block';
+			document.getElementById('spanAuthKeyBlocked').innerHTML=_("labelAuthKeyBlocked");
+			if ( language != "ru" )
+				document.getElementById('spanAuthKeyBlocked').innerHTML+="<br />"+_("labelCertBlocked");
 			document.getElementById('authValidButtons').style.display='none';
 			document.getElementById('authBlockedButtons').style.display=(pukRetry == 0 ? 'none' : 'block');
 		}
@@ -288,6 +298,9 @@ function readCardData()
 			document.getElementById('signCertStatus').innerHTML=_( esteidData.signCert.isValid() ? 'validBlocked' : 'invalidBlocked' );
 			document.getElementById('signKeyText').style.display='none';
 			document.getElementById('signKeyBlocked').style.display='block';
+			document.getElementById('spanSignKeyBlocked').innerHTML=_("labelSignKeyBlocked");
+			if ( language != "ru" )
+				document.getElementById('spanSignKeyBlocked').innerHTML+="<br />"+_("labelCertBlocked");
 			document.getElementById('signValidButtons').style.display='none';
 			document.getElementById('signBlockedButtons').style.display=(pukRetry == 0 ? 'none' : 'block');;
 		}
@@ -458,7 +471,7 @@ function setEmailActivate( msg )
 	//emails activated, lets load again
 	if ( msg == "0" )
 	{
-		document.getElementById('emailsContentActivate').style.display = "none"
+		document.getElementById('emailsContentActivate').style.display = "none";
 		extender.loadEmails();
 		return;
 	}
@@ -531,7 +544,14 @@ function handleError(msg)
 	_alert( 'error', _('errorFound') + _( msg ) )
 }
 
-function disableFields( translate )
+function handleNotice(msg)
+{
+	if ( msg == "" )
+		return;
+	_alert( 'notice', _( msg ) )
+}
+
+function disableFields()
 {
 	var divs = document.getElementsByTagName('div');
 	for( i=0;i<divs.length;i++ )
@@ -541,11 +561,9 @@ function disableFields( translate )
 		divs[i].style.display = 'none';
 	}
 
-	if ( translate != null )
-		return;
+	emailsLoaded = false;
 
 	document.getElementById('documentId').innerHTML = "";
-	document.getElementById('expiry').innerHTML = "";
 	document.getElementById('firstName').innerHTML = "";
 	document.getElementById('middleName').innerHTML = "";
 	document.getElementById('surName').innerHTML = "";
@@ -560,15 +578,21 @@ function disableFields( translate )
 	document.getElementById('emailsContent').innerHTML = "";
 	document.getElementById('photo').innerHTML = '<div id="photoContent" style="padding-top:50px;"><a href="#" onClick="loadPicture();"><trtag trcode="loadPicture">' + _('loadPicture') + '</trtag></a></div>';
 	document.getElementById('savePhoto').style.display = 'none';
-
+	document.getElementById('emailsContentActivate').style.display = "none";
+	document.getElementById('emailsContentCheckID').style.display = "none";
 
 	try {
 		if ( !cardManager.anyCardsInReader() )
 		{
+			cardManager.disableRead();
+			activeCardId = "";
 			document.getElementById('cardInfoNoCard').style.display='block';
-			document.getElementById('cardInfoNoCardText').innerHTML=_( cardManager.getReaderCount() == 0 ? 'noReaders' : 'noCard' );
+			document.getElementById('cardInfoNoCardText').innerHTML='<trtag trcode="' + ( cardManager.getReaderCount() == 0 ? 'noReaders' : 'noCard' ) + '">' + _( cardManager.getReaderCount() == 0 ? 'noReaders' : 'noCard' ) + '</trtag>';
+			if ( cardManager.getReaderCount() == 0 )
+				cardManager.newManager();
+			cardManager.allowRead();
 		}
-	} catch( err ) {}
+	} catch( err ) { cardManager.allowRead(); }
 }
 
 function enableFields()
@@ -628,10 +652,12 @@ function setMobile( result )
 
 function updateCert()
 {
+	cardManager.disableRead();
 	extender.showLoading( _('updateCert') );
 	if ( !extender.updateCertAllowed() )
 	{
 		extender.closeLoading();
+		cardManager.allowRead();
 		return;
 	}
 	var ok = false;
@@ -641,9 +667,13 @@ function updateCert()
 	if ( ok )
 	{
 		extender.closeLoading();
+		_alert( 'info', _( 'updateCertOk' ) );
 		activeCardId = "";
-		cardInserted( cardManager.activeReaderNum() );
+		var activeNum = cardManager.activeReaderNum();
+		cardManager.newManager();
+		cardInserted( activeNum );
 	}
+	cardManager.allowRead();
 	extender.closeLoading();
 }
 
@@ -843,14 +873,18 @@ function changePuk()
 	if ( !esteidData.validatePuk(oldVal) )
 	{
 		ret = esteidData.getPukRetryCount();
-		if ( ret == 0 )
+		if ( ret == 0 || ret > 3 )
 		{
 			document.getElementById('pukOldPin').value = "";
 			document.getElementById('pukNewPin').value = "";
 			document.getElementById('pukNewPin2').value = "";
-			_alert( 'error', _("PUKBlocked") );
-			readCardData();
-			setActive('cert','');
+			if ( ret == 0 )
+			{
+				_alert( 'error', _("PUKBlocked") );
+				readCardData();
+				setActive('cert','');
+			} else
+				_alert( 'error', _("PUKValidateFailed") );
 			return;
 		}
 		_alert( 'warning', _('PUKInvalidRetry').replace( /%d/, ret ) );
@@ -921,14 +955,18 @@ function unblockPin( type )
 	if ( !esteidData.validatePuk(oldVal) )
 	{
 		ret = esteidData.getPukRetryCount();
-		if ( ret == 0 )
+		if ( ret == 0 || ret > 3 )
 		{
 			document.getElementById('bpin' + type + 'OldPin').value = "";
 			document.getElementById('bpin' + type + 'NewPin').value = "";
 			document.getElementById('bpin' + type + 'NewPin2').value = "";
-			_alert( 'error', _("PUKBlocked") );
-			readCardData();
-			setActive('cert','');
+			if ( ret == 0 )
+			{
+				_alert( 'error', _("PUKBlocked") );
+				readCardData();
+				setActive('cert','');
+			} else
+				_alert( 'error', _("PUKValidateFailed") );
 			return;
 		}
 		_alert( 'warning', _("PUKInvalidRetry").replace( /%d/, ret ) );
