@@ -1,8 +1,7 @@
 /*
  * QEstEidUtil
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,7 +26,7 @@
 
 #include "jscardmanager.h"
 #include "DiagnosticsDialog.h"
-#include "smartcard++/esteid/EstEidCard.h"
+#include <smartcardpp/esteid/EstEidCard.h>
 
 using namespace std;
 
@@ -35,9 +34,10 @@ JsCardManager::JsCardManager(JsEsteidCard *jsEsteidCard)
 :	QObject( jsEsteidCard )
 ,	cardMgr( 0 )
 ,	m_jsEsteidCard( jsEsteidCard )
+,   readAllowed( true )
 {
 	try {
-		cardMgr = new SmartCardManager();
+		cardMgr = new PCSCManager();
 	} catch ( std::runtime_error &e ) {
 		qDebug() << e.what();
 	}
@@ -61,13 +61,16 @@ void JsCardManager::pollCard()
 	if ( !pollTimer.isActive() )
 		pollTimer.start( 500 );
 
+    if ( !readAllowed )
+        return;
+
 	int numReaders = 0;
     try {
 		QString insert,remove;
 		bool foundConnected = false;
 
         if (!cardMgr)
-            cardMgr = new SmartCardManager();
+            cardMgr = new PCSCManager();
 
 		// Build current device list with statuses
         QHash<QString,ReaderState> tmp;
@@ -124,18 +127,20 @@ void JsCardManager::pollCard()
 			if ( m_jsEsteidCard->m_card && m_jsEsteidCard->getDocumentId() == cardReaders[remove].cardId )
 				m_jsEsteidCard->setCard( 0 );
 			cardReaders = tmp;
-			emit cardEvent( "cardRemoved", remove != "empty" ? cardReaders[remove].id : -1 );
+            readAllowed = false;
+            emit cardEvent( "cardRemoved", remove != "empty" ? cardReaders[remove].id : -1 );
 		}
 		cardReaders = tmp;
 		if ( !insert.isEmpty() )
-			emit cardEvent( "cardInserted", insert != "empty" ? cardReaders[insert].id : -1 );
-		else if ( !foundConnected ) // Didn't find any connected reader, lets find one
-			findCard();
-		else if ( foundConnected && !m_jsEsteidCard->canReadCard() ) //card connected but not fully readable, let's try again
-		{
+        {
+            readAllowed = false;
+            emit cardEvent( "cardInserted", insert != "empty" ? cardReaders[insert].id : -1 );
+        } else if ( !foundConnected ) {// Didn't find any connected reader, lets find one
+            findCard();
+        } else if ( foundConnected && !m_jsEsteidCard->canReadCard() ) { //card connected but not fully readable, let's try again
 			findCard();
 			if ( m_jsEsteidCard->canReadCard() )
-				emit cardEvent( "cardInserted", activeReaderNum() );
+                emit cardEvent( "cardInserted", activeReaderNum() );
 		}
     } catch (std::runtime_error &e) {
 		qDebug() << e.what();
@@ -236,14 +241,14 @@ bool JsCardManager::selectReader( const ReaderState &reader )
     EstEidCard *card = 0;
     try {
         if (!cardMgr)
-            cardMgr = new SmartCardManager();
+            cardMgr = new PCSCManager();
 		card = new EstEidCard(*cardMgr);
 		card->connect( reader.id );
 		QCoreApplication::processEvents();
 		m_jsEsteidCard->setCard(card, reader.id);
         return true;
     } catch (std::runtime_error &err) {
-		//ignore Another application is using
+        //ignore Another application is using
 		if ( QString::fromStdString( err.what() ).contains( "Another " ) )
 			return false;
         handleError(err.what());
@@ -286,4 +291,20 @@ void JsCardManager::handleError(QString msg)
 }
 
 void JsCardManager::showDiagnostics()
-{ (new DiagnosticsDialog( qApp->activeWindow() ) )->show(); }
+{
+	(new DiagnosticsDialog( qApp->activeWindow() ) )->exec();
+	m_jsEsteidCard->reconnect();
+}
+
+void JsCardManager::allowRead()
+{ readAllowed = true; }
+
+void JsCardManager::disableRead()
+{ readAllowed = false; }
+
+void JsCardManager::newManager()
+{
+	m_jsEsteidCard->setCard( 0 );
+	delete cardMgr;
+	cardMgr = 0;
+}
