@@ -1,8 +1,7 @@
 /*
  * QEstEidUtil
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,8 +25,7 @@
 #include <QHash>
 #include <QTimer>
 
-#include "smartcard++/common.h"
-#include "smartcard++/SmartCardManager.h"
+#include <smartcardpp/PCSCManager.h>
 #include "jsesteidcard.h"
 
 class JsCardManager : public QObject
@@ -47,13 +45,14 @@ public:
 	~JsCardManager();
 
 private:
-    SmartCardManager *cardMgr;
+    PCSCManager *cardMgr;
 	JsEsteidCard *m_jsEsteidCard;
     QTimer pollTimer;
 
     QHash<QString,ReaderState> cardReaders;
 
     void handleError(QString msg);
+    bool readAllowed;
 
 public slots:
     int getReaderCount();
@@ -67,6 +66,9 @@ public slots:
 	void findCard();
 	bool anyCardsInReader();
 	int activeReaderNum();
+    void allowRead();
+	void disableRead();
+	void newManager();
 
 private slots:
     void pollCard();
