@@ -1,8 +1,7 @@
 /*
  * QEstEidUtil
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,8 +25,7 @@
 #include <QObject>
 #include <QSslCertificate>
 
-#include "smartcard++/common.h"
-#include "smartcard++/esteid/EstEidCard.h"
+#include <smartcardpp/esteid/EstEidCard.h>
 
 class JsCertData : public QObject
 {
@@ -64,6 +62,7 @@ public slots:
 	QString getSerialNum();
 
 	bool	isTempel();
+	bool	isTest();
 	bool	isValid();
 	int		validDays();
 };
