@@ -1,8 +1,7 @@
 /*
  * QEstEidUtil
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,12 +25,11 @@
 #include <QFileDialog>
 #include <QLocale>
 #include <QMessageBox>
-#include <QtWebKit>
+#include <QTemporaryFile>
 
 #include "CertUpdate.h"
 #include "mainwindow.h"
 #include "jsextender.h"
-#include "common/PinDialog.h"
 #include "common/Settings.h"
 #include "SettingsDialog.h"
 
@@ -40,7 +38,15 @@ JsExtender::JsExtender( MainWindow *main )
 ,	m_mainWindow( main )
 ,	m_loading( 0 )
 {
-	m_locale = Settings().value( "Main/language" ).toString();
+	QString deflang;
+	switch( QLocale().language() )
+	{
+	case QLocale::English: deflang = "en"; break;
+	case QLocale::Russian: deflang = "ru"; break;
+	case QLocale::Estonian:
+	default: deflang = "et"; break;
+	}
+	m_locale = Settings().value( "Main/Language", deflang ).toString();
 	if ( m_locale.isEmpty() )
 		m_locale = QLocale::system().name().left( 2 );
 	setLanguage( m_locale );
@@ -62,7 +68,7 @@ void JsExtender::setLanguage( const QString &lang )
 	m_locale = lang;
 	if ( m_locale == "C" )
 		m_locale = "en";
-	Settings().setValue( "Main/language", m_locale );
+	Settings().setValue( "Main/Language", m_locale );
 	m_mainWindow->retranslate( m_locale );
 }
 
@@ -200,7 +206,7 @@ void JsExtender::loadEmails()
 	}
 	if ( emails.length() > 4 )
 		emails = emails.right( emails.length() - 4 );
-	jsCall( "setEmails", result, QByteArray( QUrl::toPercentEncoding( emails, "<BR>@()- " ) ).constData() );
+	jsCall( "setEmails", result, emails );
 }
 
 QString JsExtender::readEmailAddresses()
@@ -367,11 +373,11 @@ void JsExtender::getMidStatus()
 			return;
 		}
 		MobileResult mRes = (MobileResult)e.elementsByTagName( "ResponseStatus" ).item(0).toElement().text().toInt();
-		QString mResString;
+		QString mResString, mNotice;
 		switch( mRes )
 		{
-			case NoCert: mResString = "mobileNoCert"; break;
-			case NotActive: mResString = "mobileNotActive"; break;
+			case NoCert: mNotice = "mobileNoCert"; break;
+			case NotActive: mNotice = "mobileNotActive"; break;
 			case NoIDCert: mResString = "noIDCert"; break;
 			case InternalError: mResString = "mobileInternalError"; break;
 			case InterfaceNotReady: mResString = "mobileInterfaceNotReady"; break;
@@ -383,6 +389,11 @@ void JsExtender::getMidStatus()
 			jsCall( "handleError", mResString );
 			return;
 		}
+		if ( !mNotice.isEmpty() )
+		{
+			jsCall( "handleNotice", mNotice );
+			return;
+		}
 		mResString = QString( "%1;%2;%3;%4" )
 						.arg( e.elementsByTagName( "MSISDN" ).item(0).toElement().text() )
 						.arg( e.elementsByTagName( "Operator" ).item(0).toElement().text() )
@@ -441,7 +452,8 @@ bool JsExtender::updateCertAllowed()
 	QMessageBox::StandardButton b = QMessageBox::warning( m_mainWindow, tr("Certificate update"),
 		tr("For updating certificates please close all programs which are interacting with smartcard "
 		   "(qdigidocclient, qdigidoccrypto, Firefox, Safari, Internet Explorer...)<br />"
-		   "After updating certificates it is not possible decypt documents!"),
+		   "After updating certificates it will no longer be possible to decrypt documents that were encrypted with the old certificate.<br />"
+		   "Do you want to continue?"),
 		QMessageBox::Yes|QMessageBox::No, QMessageBox::No );
 	if( b == QMessageBox::No )
 		return false;
@@ -450,7 +462,7 @@ bool JsExtender::updateCertAllowed()
 		CertUpdate *c = new CertUpdate( m_mainWindow->cardManager()->activeReaderNum(), this );
 		result = c->checkUpdateAllowed();
 	} catch ( std::runtime_error &e ) {
-		QMessageBox::warning( m_mainWindow, tr( "Certificate update" ), tr("Certificate update failed:<br />%1").arg( e.what() ), QMessageBox::Ok );
+		QMessageBox::warning( m_mainWindow, tr( "Certificate update" ), tr("Certificate update failed:<br />%1").arg( QString::fromUtf8( e.what() ) ), QMessageBox::Ok );
 	}
 	return result;
 }
@@ -462,14 +474,11 @@ bool JsExtender::updateCert()
 		CertUpdate *c = new CertUpdate( m_mainWindow->cardManager()->activeReaderNum(), this );
 		if ( c->checkUpdateAllowed() && m_mainWindow->eidCard()->m_authCert )
 		{
-			PinDialog p( PinDialog::Pin1Type, m_mainWindow->eidCard()->m_authCert->cert(), qApp->activeWindow() );
-			if( !p.exec() )
-				return false;
-			c->startUpdate( p.text() );
+			c->startUpdate();
 			result = true;
 		}
 	} catch ( std::runtime_error &e ) {
-		QMessageBox::warning( m_mainWindow, tr( "Certificate update" ), tr("Certificate update failed: %1").arg( e.what() ), QMessageBox::Ok );
+		QMessageBox::warning( m_mainWindow, tr( "Certificate update" ), tr("Certificate update failed: %1").arg( QString::fromUtf8( e.what() ) ), QMessageBox::Ok );
 	}
 	return result;
 }
