@@ -11,6 +11,22 @@
         <source>Check internet connection</source>
         <translation>kontrollige interneti ühendust</translation>
     </message>
+    <message>
+        <source>Server sai vale arvu baite, samm: %1</source>
+        <translation>Server sai vale arvu baite, samm: %1</translation>
+    </message>
+    <message>
+        <source>Serveri töös tekkisid vead, samm: %1</source>
+        <translation>Serveri töös tekkisid vead, samm: %1</translation>
+    </message>
+    <message>
+        <source>Kaardi vastuse parsimisel tekkis viga, samm: %1</source>
+        <translation>Kaardi vastuse parsimisel tekkis viga, samm: %1</translation>
+    </message>
+    <message>
+        <source>Sertifitseerimiskeskus ei vasta, samm: %1</source>
+        <translation>Sertifitseerimiskeskus ei vasta, samm: %1</translation>
+    </message>
 </context>
 <context>
     <name>DiagnosticsDialog</name>
@@ -47,7 +63,7 @@
         <translation>Teksti failid (*.txt)</translation>
     </message>
     <message>
-        <source>Error occured</source>
+        <source>Error occurred</source>
         <translation>Tekkis viga</translation>
     </message>
     <message>
@@ -64,11 +80,11 @@
     </message>
     <message>
         <source>Smart Card service status: </source>
-        <translation>Smart Card teenuse staatus:</translation>
+        <translation>Smart Card teenuse staatus: </translation>
     </message>
     <message>
         <source>PCSC service status: </source>
-        <translation>PCSC teenuse staatus:</translation>
+        <translation>PCSC teenuse staatus: </translation>
     </message>
     <message>
         <source>Running</source>
@@ -95,7 +111,7 @@
     </message>
     <message>
         <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;TIFF (*.tif *.tiff);;24-bit Bitmap (*.bmp)</source>
-        <translation></translation>
+        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;TIFF (*.tif *.tiff);;24-bit Bitmap (*.bmp)</translation>
     </message>
     <message>
         <source>Save picture</source>
@@ -109,17 +125,13 @@
         <source>Certificate update failed: %1</source>
         <translation>Sertifikaatide uuendamine ebaõnnestus: %1</translation>
     </message>
-    <message>
-        <source>Certificate update not allowed!</source>
-        <translation type="obsolete">Sertifikaati uuendamine ei ole lubatud!</translation>
-    </message>
     <message>
         <source>Certificate update failed:&lt;br /&gt;%1</source>
         <translation>Sertifikaatide uuendamine ebaõnnestus:&lt;br /&gt;%1</translation>
     </message>
     <message>
-        <source>For updating certificates please close all programs which are interacting with smartcard (qdigidocclient, qdigidoccrypto, Firefox, Safari, Internet Explorer...)&lt;br /&gt;After updating certificates it is not possible decypt documents!</source>
-        <translation>Sertifikaatite uuendamiseks palun sulgege kõik rakendused, mis kasutavad ID-kaarti (ID-kaardi klient, haldusvahend, Firefox, Safari, Internet Explorer...)&lt;br /&gt;Pärast sertifikaatide uuendamist ei ole võimalik enam dekrüpteerida vana sertifikaadiga krüpteeritud dokumente!</translation>
+        <source>For updating certificates please close all programs which are interacting with smartcard (qdigidocclient, qdigidoccrypto, Firefox, Safari, Internet Explorer...)&lt;br /&gt;After updating certificates it will no longer be possible to decrypt documents that were encrypted with the old certificate.&lt;br /&gt;Do you want to continue?</source>
+        <translation>Sertifikaatite uuendamiseks palun sulgege kõik rakendused, mis kasutavad ID-kaarti (Klient, Krüpto, Firefox, Safari, Internet Explorer...)&lt;br /&gt;Pärast sertifikaatide uuendamist ei ole võimalik enam dekrüpteerida vana sertifikaadiga krüpteeritud dokumente!&lt; br /&gt;Kas soovite jätkata sertifikaatide uuendamisega?</translation>
     </message>
 </context>
 <context>
