@@ -11,6 +11,22 @@
         <source>Check internet connection</source>
         <translation>Проверте подключение к интернету</translation>
     </message>
+    <message>
+        <source>Server sai vale arvu baite, samm: %1</source>
+        <translation>Сервер получил неправильное количество байтов, шаг: %1</translation>
+    </message>
+    <message>
+        <source>Serveri töös tekkisid vead, samm: %1</source>
+        <translation>В работе сервера произошла ошибка, шаг: %1</translation>
+    </message>
+    <message>
+        <source>Kaardi vastuse parsimisel tekkis viga, samm: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sertifitseerimiskeskus ei vasta, samm: %1</source>
+        <translation>Центр сертифицирования не отвечает, шаг: %1</translation>
+    </message>
 </context>
 <context>
     <name>DiagnosticsDialog</name>
@@ -32,11 +48,11 @@
     </message>
     <message>
         <source>Smart Card service status: </source>
-        <translation>Статус Smart Card сервиса:</translation>
+        <translation>Статус Smart Card сервиса: </translation>
     </message>
     <message>
         <source>PCSC service status: </source>
-        <translation>Статус PCSC сервиса:</translation>
+        <translation>Статус PCSC сервиса: </translation>
     </message>
     <message>
         <source>Running</source>
@@ -71,7 +87,7 @@
         <translation>Текстовые файлы (*.txt)</translation>
     </message>
     <message>
-        <source>Error occured</source>
+        <source>Error occurred</source>
         <translation>Возникла ошибка</translation>
     </message>
     <message>
@@ -99,7 +115,7 @@
     </message>
     <message>
         <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;TIFF (*.tif *.tiff);;24-bit Bitmap (*.bmp)</source>
-        <translation></translation>
+        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;TIFF (*.tif *.tiff);;24-bit Bitmap (*.bmp)</translation>
     </message>
     <message>
         <source>Certificate update</source>
@@ -109,17 +125,13 @@
         <source>Certificate update failed: %1</source>
         <translation>Неудачное обновление сертификата: %1</translation>
     </message>
-    <message>
-        <source>Certificate update not allowed!</source>
-        <translation type="obsolete">Обновление сертификата не разрешено!</translation>
-    </message>
     <message>
         <source>Certificate update failed:&lt;br /&gt;%1</source>
         <translation>Неудачное обновление сертификата:&lt;br /&gt;%1</translation>
     </message>
     <message>
-        <source>For updating certificates please close all programs which are interacting with smartcard (qdigidocclient, qdigidoccrypto, Firefox, Safari, Internet Explorer...)&lt;br /&gt;After updating certificates it is not possible decypt documents!</source>
-        <translation type="unfinished">Для обновления сертификата пожалуйста закройте все приложения, которые используют ID-карту (qdigidocclient, qdigidoccrypto, Firefox, Safari, Internet Explorer...)&lt;br /&gt;После обновления сертификатов шифровка документов невозможна!</translation>
+        <source>For updating certificates please close all programs which are interacting with smartcard (qdigidocclient, qdigidoccrypto, Firefox, Safari, Internet Explorer...)&lt;br /&gt;After updating certificates it will no longer be possible to decrypt documents that were encrypted with the old certificate.&lt;br /&gt;Do you want to continue?</source>
+        <translation>Для обновления сертификата пожалуйста закройте все приложения, которые используют ID-карту (Клиент, Crypto, Firefox, Safari, Internet Explorer...)&lt;br /&gt;После обновления сертификатов шифровка документов будет невозможна!&lt;br /&gt;Хотите продолжить?</translation>
     </message>
 </context>
 <context>
